from mastercardapicore import *

# import apis resourceconfig
from mastercardmcon.resourceconfig import ResourceConfig


# import apis into api package
from mastercardmcon.airport import *
from mastercardmcon.benefits import *
from mastercardmcon.bundleprofile import *
from mastercardmcon.insurance import *
from mastercardmcon.offers import *
from mastercardmcon.wifi import *
